=======
rtsstat
=======

.. image:: https://github.com/waseju/rtsstat/workflows/Build%20rtsstat%20Package/badge.svg
        :target: https://github.com/waseju/rtsstat/workflows/Build%20rtsstat%20Package/badge.svg
        :alt: Github Workflow Build rtsstat Status

.. image:: https://github.com/waseju/rtsstat/workflows/Run%20rtsstat%20Tox%20Test%20Suite/badge.svg
        :target: https://github.com/waseju/rtsstat/workflows/Run%20rtsstat%20Tox%20Test%20Suite/badge.svg
        :alt: Github Workflow Tests Status

.. image:: https://img.shields.io/pypi/v/rtsstat.svg
        :target: https://pypi.python.org/pypi/rtsstat
        :alt: PyPI Status


.. image:: https://readthedocs.org/projects/rtsstat/badge/?version=latest
        :target: https://rtsstat.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://flat.badgen.net/dependabot/thepracticaldev/dev.to?icon=dependabot
        :target: https://flat.badgen.net/dependabot/thepracticaldev/dev.to?icon=dependabot
        :alt: Dependabot Enabled


rtsstat. A mlf-core based .


* Free software: MIT
* Documentation: https://rtsstat.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with mlf-core_ using cookiecutter_.

.. _mlf-core: https://mlf-core.com
.. _cookiecutter: https://github.com/audreyr/cookiecutter
